@@ -10,11 +10,19 @@ Usage::
     client: RedshiftDataAPIServiceClient = boto3.client("redshift-data")
     ```
 """
-import sys
 from typing import Any, Dict, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_redshift_data.literals import (
+    DescribeTablePaginatorName,
+    GetStatementResultPaginatorName,
+    ListDatabasesPaginatorName,
+    ListSchemasPaginatorName,
+    ListStatementsPaginatorName,
+    ListTablesPaginatorName,
+    StatusString,
+)
 from mypy_boto3_redshift_data.paginator import (
     DescribeTablePaginator,
     GetStatementResultPaginator,
@@ -35,12 +43,6 @@ from mypy_boto3_redshift_data.type_defs import (
     ListTablesResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("RedshiftDataAPIServiceClient",)
 
 
@@ -166,9 +168,7 @@ class RedshiftDataAPIServiceClient:
         NextToken: str = None,
         RoleLevel: bool = None,
         StatementName: str = None,
-        Status: Literal[
-            "SUBMITTED", "PICKED", "STARTED", "FINISHED", "ABORTED", "FAILED", "ALL"
-        ] = None,
+        Status: StatusString = None,
     ) -> ListStatementsResponseTypeDef:
         """
         [Client.list_statements documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_statements)
@@ -191,39 +191,39 @@ class RedshiftDataAPIServiceClient:
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["describe_table"]) -> DescribeTablePaginator:
+    def get_paginator(self, operation_name: DescribeTablePaginatorName) -> DescribeTablePaginator:
         """
         [Paginator.DescribeTable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["get_statement_result"]
+        self, operation_name: GetStatementResultPaginatorName
     ) -> GetStatementResultPaginator:
         """
         [Paginator.GetStatementResult documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_databases"]) -> ListDatabasesPaginator:
+    def get_paginator(self, operation_name: ListDatabasesPaginatorName) -> ListDatabasesPaginator:
         """
         [Paginator.ListDatabases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_schemas"]) -> ListSchemasPaginator:
+    def get_paginator(self, operation_name: ListSchemasPaginatorName) -> ListSchemasPaginator:
         """
         [Paginator.ListSchemas documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_statements"]) -> ListStatementsPaginator:
+    def get_paginator(self, operation_name: ListStatementsPaginatorName) -> ListStatementsPaginator:
         """
         [Paginator.ListStatements documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_tables"]) -> ListTablesPaginator:
+    def get_paginator(self, operation_name: ListTablesPaginatorName) -> ListTablesPaginator:
         """
         [Paginator.ListTables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables)
         """
