@@ -26,11 +26,11 @@ Usage::
     list_tables_paginator: ListTablesPaginator = client.get_paginator("list_tables")
     ```
 """
-import sys
 from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
+from mypy_boto3_redshift_data.literals import StatusString
 from mypy_boto3_redshift_data.type_defs import (
     DescribeTableResponseTypeDef,
     GetStatementResultResponseTypeDef,
@@ -41,12 +41,6 @@ from mypy_boto3_redshift_data.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "DescribeTablePaginator",
     "GetStatementResultPaginator",
@@ -138,9 +132,7 @@ class ListStatementsPaginator(Boto3Paginator):
         self,
         RoleLevel: bool = None,
         StatementName: str = None,
-        Status: Literal[
-            "SUBMITTED", "PICKED", "STARTED", "FINISHED", "ABORTED", "FAILED", "ALL"
-        ] = None,
+        Status: StatusString = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListStatementsResponseTypeDef]:
         """
