@@ -13,10 +13,8 @@ import sys
 from datetime import datetime
 from typing import IO, Any, Dict, List, Union
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_redshift_data.literals import StatusString
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -93,7 +91,7 @@ _OptionalStatementDataTypeDef = TypedDict(
         "QueryString": str,
         "SecretArn": str,
         "StatementName": str,
-        "Status": Literal["SUBMITTED", "PICKED", "STARTED", "FINISHED", "ABORTED", "FAILED", "ALL"],
+        "Status": StatusString,
         "UpdatedAt": datetime,
     },
     total=False,
@@ -131,7 +129,7 @@ _OptionalDescribeStatementResponseTypeDef = TypedDict(
         "ResultRows": int,
         "ResultSize": int,
         "SecretArn": str,
-        "Status": Literal["SUBMITTED", "PICKED", "STARTED", "FINISHED", "ABORTED", "FAILED", "ALL"],
+        "Status": StatusString,
         "UpdatedAt": datetime,
     },
     total=False,
